pub struct CommandPlan {
pub argv: Vec<String>,
pub env: BTreeMap<String, String>,
pub explicit_env: Vec<String>,
pub pass_env: Vec<String>,
pub cwd: PathBuf,
}Fields
argv: Vec<String>env: BTreeMap<String, String>explicit_env: Vec<String>Variables explicitly rendered by resolution or an integration, as distinct from ambient environment composed for local execution.
pass_env: Vec<String>Names whose values flow from the launching machine into a containerized process without projecting remote values into the plan.
cwd: PathBufTrait Implementations
Sourceimpl Clone for CommandPlan
impl Clone for CommandPlan
Sourcefn clone(&self) -> CommandPlan
fn clone(&self) -> CommandPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandPlan
impl Debug for CommandPlan
Sourceimpl<'de> Deserialize<'de> for CommandPlan
impl<'de> Deserialize<'de> for CommandPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more